@@ -21,20 +21,20 @@ import uiRoutes from 'ui/routes';
 import template from './index.html';
 
 require('brace');
-require('ui-bootstrap-custom');
 
-require('ui/modules').get('kibana', ['sense.ui.bootstrap']);
-require('ui/tooltip');
 require('ui/autoload/styles');
+require('ui/capabilities/route_setup');
 
 require('./src/controllers/sense_controller');
 require('./src/directives/sense_history');
 require('./src/directives/sense_settings');
 require('./src/directives/sense_help');
 require('./src/directives/sense_welcome');
+require('./src/directives/console_menu_directive');
 
 
 uiRoutes.when('/dev_tools/console', {
+  requireUICapability: 'dev_tools.show',
   controller: 'SenseController',
   template,
 });
