@@ -19,11 +19,13 @@
 
 require('./sense_help_example');
 
+import { i18n } from '@kbn/i18n';
+
 const storage = require('../storage');
 
 require('ui/modules')
   .get('app/sense')
-  .directive('senseWelcome', function (i18n) {
+  .directive('senseWelcome', function () {
     return {
       restrict: 'E',
       template: require('./welcome.html'),
@@ -31,7 +33,7 @@ require('ui/modules')
         $scope.$on('$destroy', function () {
           storage.set('version_welcome_shown', '@@SENSE_REVISION');
         });
-        $scope.asWellAsFragmentText = i18n('console.welcomePage.supportedRequestFormatDescription.asWellAsFragmentText', {
+        $scope.asWellAsFragmentText = i18n.translate('console.welcomePage.supportedRequestFormatDescription.asWellAsFragmentText', {
           defaultMessage: 'as well as'
         });
       },
