@@ -18,6 +18,7 @@
  */
 
 import _ from 'lodash';
+import { i18n } from '@kbn/i18n';
 import React from 'react';
 import angular from 'angular';
 import { uiModules } from 'ui/modules';
@@ -25,7 +26,6 @@ import chrome from 'ui/chrome';
 import { wrapInI18nContext } from 'ui/i18n';
 import { toastNotifications } from 'ui/notify';
 
-import 'ui/search_bar';
 import 'ui/apply_filters';
 
 import { panelActionsStore } from './store/panel_actions_store';
@@ -48,7 +48,7 @@ import { showOptionsPopover } from './top_nav/show_options_popover';
 import { showNewVisModal } from '../visualize/wizard';
 import { showShareContextMenu, ShareContextMenuExtensionsRegistryProvider } from 'ui/share';
 import { migrateLegacyQuery } from 'ui/utils/migrate_legacy_query';
-import * as filterActions from 'ui/doc_table/actions/filter';
+import * as filterActions from 'plugins/kibana/discover/doc_table/actions/filter';
 import { FilterManagerProvider } from 'ui/filter_manager';
 import { EmbeddableFactoriesRegistryProvider } from 'ui/embeddable/embeddable_factories_registry';
 import { ContextMenuActionsRegistryProvider } from 'ui/embeddable';
@@ -58,6 +58,9 @@ import { getUnhashableStatesProvider } from 'ui/state_management/state_hashing';
 
 import { DashboardViewportProvider } from './viewport/dashboard_viewport_provider';
 
+import { data } from 'plugins/data';
+data.search.loadLegacyDirectives();
+
 const app = uiModules.get('app/dashboard', [
   'elasticsearch',
   'ngRoute',
@@ -89,8 +92,7 @@ app.directive('dashboardApp', function ($injector) {
       $routeParams,
       getAppState,
       dashboardConfig,
-      localStorage,
-      i18n,
+      localStorage
     ) {
       const filterManager = Private(FilterManagerProvider);
       const queryFilter = Private(FilterBarQueryFilterProvider);
@@ -121,6 +123,8 @@ app.directive('dashboardApp', function ($injector) {
 
       $scope.getDashboardState = () => dashboardStateManager;
       $scope.appState = dashboardStateManager.getAppState();
+      $scope.refreshInterval = timefilter.getRefreshInterval();
+
 
       // The 'previouslyStored' check is so we only update the time filter on dashboard open, not during
       // normal cross app navigation.
@@ -141,6 +145,7 @@ app.directive('dashboardApp', function ($injector) {
           refreshInterval: timefilter.getRefreshInterval(),
         };
         $scope.panels = dashboardStateManager.getPanels();
+        $scope.screenTitle = dashboardStateManager.getTitle();
 
         const panelIndexPatterns = dashboardStateManager.getPanelIndexPatterns();
         if (panelIndexPatterns && panelIndexPatterns.length > 0) {
@@ -183,6 +188,7 @@ app.directive('dashboardApp', function ($injector) {
         courier.fetch();
       };
       dashboardStateManager.handleTimeChange(timefilter.getTime());
+      dashboardStateManager.handleRefreshConfigChange(timefilter.getRefreshInterval());
 
       $scope.expandedPanel = null;
       $scope.dashboardViewMode = dashboardStateManager.getViewMode();
@@ -198,7 +204,7 @@ app.directive('dashboardApp', function ($injector) {
       const updateBreadcrumbs = () => {
         chrome.breadcrumbs.set([
           {
-            text: i18n('kbn.dashboard.dashboardAppBreadcrumbsTitle', {
+            text: i18n.translate('kbn.dashboard.dashboardAppBreadcrumbsTitle', {
               defaultMessage: 'Dashboard',
             }),
             href: $scope.landingPageUrl()
@@ -292,7 +298,10 @@ app.directive('dashboardApp', function ($injector) {
         // directly passed down time filter. Then we can get rid of this reliance on scope broadcasts.
         $scope.refresh();
       });
-      $scope.$listenAndDigestAsync(timefilter, 'refreshIntervalUpdate', updateState);
+      $scope.$listenAndDigestAsync(timefilter, 'refreshIntervalUpdate', () => {
+        dashboardStateManager.handleRefreshConfigChange(timefilter.getRefreshInterval());
+        updateState();
+      });
       $scope.$listenAndDigestAsync(timefilter, 'timeUpdate', updateState);
 
       function updateViewMode(newMode) {
@@ -326,20 +335,20 @@ app.directive('dashboardApp', function ($injector) {
         }
 
         confirmModal(
-          i18n('kbn.dashboard.changeViewModeConfirmModal.discardChangesDescription',
+          i18n.translate('kbn.dashboard.changeViewModeConfirmModal.discardChangesDescription',
             { defaultMessage: `Once you discard your changes, there's no getting them back.` }
           ),
           {
             onConfirm: revertChangesAndExitEditMode,
             onCancel: _.noop,
-            confirmButtonText: i18n('kbn.dashboard.changeViewModeConfirmModal.confirmButtonLabel',
+            confirmButtonText: i18n.translate('kbn.dashboard.changeViewModeConfirmModal.confirmButtonLabel',
               { defaultMessage: 'Discard changes' }
             ),
-            cancelButtonText: i18n('kbn.dashboard.changeViewModeConfirmModal.cancelButtonLabel',
+            cancelButtonText: i18n.translate('kbn.dashboard.changeViewModeConfirmModal.cancelButtonLabel',
               { defaultMessage: 'Continue editing' }
             ),
             defaultFocusedButton: ConfirmationButtonTypes.CANCEL,
-            title: i18n('kbn.dashboard.changeViewModeConfirmModal.discardChangesTitle',
+            title: i18n.translate('kbn.dashboard.changeViewModeConfirmModal.discardChangesTitle',
               { defaultMessage: 'Discard changes to dashboard?' }
             )
           }
@@ -363,7 +372,7 @@ app.directive('dashboardApp', function ($injector) {
           .then(function (id) {
             if (id) {
               toastNotifications.addSuccess({
-                title: i18n('kbn.dashboard.dashboardWasSavedSuccessMessage',
+                title: i18n.translate('kbn.dashboard.dashboardWasSavedSuccessMessage',
                   {
                     defaultMessage: `Dashboard '{dashTitle}' was saved`,
                     values: { dashTitle: dash.title },
@@ -382,7 +391,7 @@ app.directive('dashboardApp', function ($injector) {
             return { id };
           }).catch((error) => {
             toastNotifications.addDanger({
-              title: i18n('kbn.dashboard.dashboardWasNotSavedDangerMessage',
+              title: i18n.translate('kbn.dashboard.dashboardWasNotSavedDangerMessage',
                 {
                   defaultMessage: `Dashboard '{dashTitle}' was not saved. Error: {errorMessage}`,
                   values: {
@@ -475,7 +484,7 @@ app.directive('dashboardApp', function ($injector) {
           showNewVisModal(visTypes, { editorParams: [DashboardConstants.ADD_VISUALIZATION_TO_DASHBOARD_MODE_PARAM] });
         };
 
-        showAddPanel(dashboardStateManager.addNewPanel, addNewVis, visTypes);
+        showAddPanel(dashboardStateManager.addNewPanel, addNewVis, embeddableFactories);
       };
       navActions[TopNavIds.OPTIONS] = (menuItem, navController, anchorElement) => {
         showOptionsPopover({
@@ -494,6 +503,7 @@ app.directive('dashboardApp', function ($injector) {
         showShareContextMenu({
           anchorElement,
           allowEmbed: true,
+          allowShortUrl: !dashboardConfig.getHideWriteControls(),
           getUnhashableStates,
           objectId: dash.id,
           objectType: 'dashboard',
@@ -508,15 +518,20 @@ app.directive('dashboardApp', function ($injector) {
       updateViewMode(dashboardStateManager.getViewMode());
 
       // update root source when filters update
-      $scope.$listen(queryFilter, 'update', function () {
-        $scope.model.filters = queryFilter.getFilters();
-        dashboardStateManager.applyFilters($scope.model.query, $scope.model.filters);
+      this.updateSubscription = queryFilter.getUpdates$().subscribe({
+        next: () => {
+          $scope.model.filters = queryFilter.getFilters();
+          dashboardStateManager.applyFilters($scope.model.query, $scope.model.filters);
+        }
       });
 
       // update data when filters fire fetch event
-      $scope.$listen(queryFilter, 'fetch', $scope.refresh);
+
+      this.fetchSubscription = queryFilter.getFetches$().subscribe($scope.refresh);
 
       $scope.$on('$destroy', () => {
+        this.updateSubscription.unsubscribe();
+        this.fetchSubscription.unsubscribe();
         dashboardStateManager.destroy();
       });
 
