@@ -34,6 +34,7 @@ import {
   updateDescription,
   updateHidePanelTitles,
   updateTimeRange,
+  updateRefreshConfig,
   clearStagedFilters,
   updateFilters,
   updateQuery,
@@ -151,6 +152,13 @@ export class DashboardStateManager {
     }));
   }
 
+  handleRefreshConfigChange({ pause, value }) {
+    store.dispatch(updateRefreshConfig({
+      isPaused: pause,
+      interval: value,
+    }));
+  }
+
   /**
    * Changes made to app state outside of direct calls to this class will need to be propagated to the store.
    * @private
@@ -238,9 +246,9 @@ export class DashboardStateManager {
 
     _.forEach(getEmbeddables(store.getState()), (embeddable, panelId) => {
       if (embeddable.initialized && !this.panelIndexPatternMapping.hasOwnProperty(panelId)) {
-        const indexPattern = getEmbeddableMetadata(store.getState(), panelId).indexPattern;
-        if (indexPattern) {
-          this.panelIndexPatternMapping[panelId] = indexPattern;
+        const embeddableMetadata = getEmbeddableMetadata(store.getState(), panelId);
+        if (embeddableMetadata.indexPatterns) {
+          this.panelIndexPatternMapping[panelId] = _.compact(embeddableMetadata.indexPatterns);
           this.dirty = true;
         }
       }
@@ -274,14 +282,15 @@ export class DashboardStateManager {
   }
 
   getPanelIndexPatterns() {
-    return _.uniq(Object.values(this.panelIndexPatternMapping), 'id');
+    const indexPatterns = _.flatten(Object.values(this.panelIndexPatternMapping));
+    return _.uniq(indexPatterns, 'id');
   }
 
   /**
    * Resets the state back to the last saved version of the dashboard.
    */
   resetState() {
-    // In order to show the correct warning for the saved-object-save-as-check-box we have to store the unsaved
+    // In order to show the correct warning, we have to store the unsaved
     // title on the dashboard object. We should fix this at some point, but this is how all the other object
     // save panels work at the moment.
     this.savedDashboard.title = this.savedDashboard.lastSavedTitle;
@@ -332,9 +341,6 @@ export class DashboardStateManager {
 
   setTitle(title) {
     this.appState.title = title;
-    // The saved-object-save-as-check-box shows a warning if the current object title is different then
-    // the existing object title. It calculates this difference by comparing this.dashboard.title to
-    // this.dashboard.lastSavedTitle, so we need to push the temporary, unsaved title, onto the dashboard.
     this.savedDashboard.title = title;
     this.saveState();
   }
