@@ -20,9 +20,9 @@
 import 'ngreact';
 import React, { Fragment } from 'react';
 import { uiModules } from 'ui/modules';
-import chrome from 'ui/chrome';
 import { wrapInI18nContext } from 'ui/i18n';
 import { FormattedMessage } from '@kbn/i18n/react';
+import { getNewPlatform } from 'ui/new_platform';
 
 import {
   EuiFlexGroup,
@@ -40,7 +40,7 @@ const DiscoverFetchError = ({ fetchError }) => {
   let body;
 
   if (fetchError.lang === 'painless') {
-    const managementUrl = chrome.getNavLinkById('kibana:management').url;
+    const managementUrl = getNewPlatform().start.core.chrome.navLinks.get('kibana:management').url;
     const url = `${managementUrl}/kibana/index_patterns`;
 
     body = (
