@@ -54,7 +54,9 @@ export function replaceTemplateStrings(text, params = {}) {
           filebeat: documentationLinks.filebeat.base,
           metricbeat: documentationLinks.metricbeat.base,
           heartbeat: documentationLinks.heartbeat.base,
-          functionbeat: documentationLinks.functionbeat.base
+          functionbeat: documentationLinks.functionbeat.base,
+          winlogbeat: documentationLinks.winlogbeat.base,
+          auditbeat: documentationLinks.auditbeat.base,
         },
         logstash: documentationLinks.logstash.base,
         version: DOC_LINK_VERSION
