@@ -18,12 +18,14 @@
  */
 
 import _ from 'lodash';
+import { i18n } from '@kbn/i18n';
 import '../saved_visualizations/saved_visualizations';
 import './visualization_editor';
 import 'ui/vis/editors/default/sidebar';
 import 'ui/visualize';
 import 'ui/collapsible_sidebar';
-import 'ui/search_bar';
+
+import { capabilities } from 'ui/capabilities';
 import 'ui/apply_filters';
 import chrome from 'ui/chrome';
 import React from 'react';
@@ -51,20 +53,24 @@ import { getUnhashableStatesProvider } from 'ui/state_management/state_hashing';
 import { showSaveModal } from 'ui/saved_objects/show_saved_object_save_modal';
 import { SavedObjectSaveModal } from 'ui/saved_objects/components/saved_object_save_modal';
 import { getEditBreadcrumbs, getCreateBreadcrumbs } from '../breadcrumbs';
+import { getNewPlatform } from 'ui/new_platform';
+
+import { data } from 'plugins/data';
+data.search.loadLegacyDirectives();
 
 uiRoutes
   .when(VisualizeConstants.CREATE_PATH, {
     template: editorTemplate,
     k7Breadcrumbs: getCreateBreadcrumbs,
     resolve: {
-      savedVis: function (savedVisualizations, redirectWhenMissing, $route, Private, i18n) {
+      savedVis: function (savedVisualizations, redirectWhenMissing, $route, Private) {
         const visTypes = Private(VisTypesRegistryProvider);
         const visType = _.find(visTypes, { name: $route.current.params.type });
         const shouldHaveIndex = visType.requiresSearch && visType.options.showIndexSelection;
         const hasIndex = $route.current.params.indexPattern || $route.current.params.savedSearchId;
         if (shouldHaveIndex && !hasIndex) {
           throw new Error(
-            i18n('kbn.visualize.createVisualization.noIndexPatternOrSavedSearchIdErrorMessage', {
+            i18n.translate('kbn.visualize.createVisualization.noIndexPatternOrSavedSearchIdErrorMessage', {
               defaultMessage: 'You must provide either an indexPattern or a savedSearchId',
             })
           );
@@ -127,8 +133,7 @@ function VisEditor(
   Promise,
   config,
   kbnBaseUrl,
-  localStorage,
-  i18n
+  localStorage
 ) {
   const docTitle = Private(DocTitleProvider);
   const queryFilter = Private(FilterBarQueryFilterProvider);
@@ -147,9 +152,9 @@ function VisEditor(
     dirty: !savedVis.id
   };
 
-  $scope.topNavMenu = [{
-    key: i18n('kbn.topNavMenu.saveVisualizationButtonLabel', { defaultMessage: 'save' }),
-    description: i18n('kbn.visualize.topNavMenu.saveVisualizationButtonAriaLabel', {
+  $scope.topNavMenu = [...(capabilities.get().visualize.save ? [{
+    key: i18n.translate('kbn.topNavMenu.saveVisualizationButtonLabel', { defaultMessage: 'save' }),
+    description: i18n.translate('kbn.visualize.topNavMenu.saveVisualizationButtonAriaLabel', {
       defaultMessage: 'Save Visualization',
     }),
     testId: 'visualizeSaveButton',
@@ -158,7 +163,7 @@ function VisEditor(
     },
     tooltip() {
       if (vis.dirty) {
-        return i18n('kbn.visualize.topNavMenu.saveVisualizationDisabledButtonTooltip', {
+        return i18n.translate('kbn.visualize.topNavMenu.saveVisualizationDisabledButtonTooltip', {
           defaultMessage: 'Apply or Discard your changes before saving'
         });
       }
@@ -200,9 +205,9 @@ function VisEditor(
         />);
       showSaveModal(saveModal);
     }
-  }, {
-    key: i18n('kbn.topNavMenu.shareVisualizationButtonLabel', { defaultMessage: 'share' }),
-    description: i18n('kbn.visualize.topNavMenu.shareVisualizationButtonAriaLabel', {
+  }] : []), {
+    key: i18n.translate('kbn.topNavMenu.shareVisualizationButtonLabel', { defaultMessage: 'share' }),
+    description: i18n.translate('kbn.visualize.topNavMenu.shareVisualizationButtonAriaLabel', {
       defaultMessage: 'Share Visualization',
     }),
     testId: 'shareTopNavButton',
@@ -212,6 +217,7 @@ function VisEditor(
       showShareContextMenu({
         anchorElement,
         allowEmbed: true,
+        allowShortUrl: capabilities.get().visualize.createShortUrl,
         getUnhashableStates,
         objectId: savedVis.id,
         objectType: 'visualization',
@@ -223,8 +229,8 @@ function VisEditor(
       });
     }
   }, {
-    key: i18n('kbn.topNavMenu.openInspectorButtonLabel', { defaultMessage: 'inspect' }),
-    description: i18n('kbn.visualize.topNavMenu.openInspectorButtonAriaLabel', {
+    key: i18n.translate('kbn.topNavMenu.openInspectorButtonLabel', { defaultMessage: 'inspect' }),
+    description: i18n.translate('kbn.visualize.topNavMenu.openInspectorButtonAriaLabel', {
       defaultMessage: 'Open Inspector for visualization',
     }),
     testId: 'openInspectorButton',
@@ -232,18 +238,22 @@ function VisEditor(
       return !vis.hasInspector || !vis.hasInspector();
     },
     run() {
-      vis.openInspector().bindToAngularScope($scope);
+      const inspectorSession = vis.openInspector();
+      // Close the inspector if this scope is destroyed (e.g. because the user navigates away).
+      const removeWatch = $scope.$on('$destroy', () => inspectorSession.close());
+      // Remove that watch in case the user closes the inspector session herself.
+      inspectorSession.onClose.finally(removeWatch);
     },
     tooltip() {
       if (!vis.hasInspector || !vis.hasInspector()) {
-        return i18n('kbn.visualize.topNavMenu.openInspectorDisabledButtonTooltip', {
+        return i18n.translate('kbn.visualize.topNavMenu.openInspectorDisabledButtonTooltip', {
           defaultMessage: `This visualization doesn't support any inspectors.`,
         });
       }
     }
   }, {
-    key: i18n('kbn.topNavMenu.refreshButtonLabel', { defaultMessage: 'refresh' }),
-    description: i18n('kbn.visualize.topNavMenu.refreshButtonAriaLabel', {
+    key: i18n.translate('kbn.topNavMenu.refreshButtonLabel', { defaultMessage: 'refresh' }),
+    description: i18n.translate('kbn.visualize.topNavMenu.refreshButtonAriaLabel', {
       defaultMessage: 'Refresh',
     }),
     run: function () {
@@ -333,6 +343,7 @@ function VisEditor(
 
     $scope.searchSource = searchSource;
     $scope.state = $state;
+    $scope.refreshInterval = timefilter.getRefreshInterval();
 
     // Create a PersistedState instance.
     $scope.uiState = $state.makeStateful('uiState');
@@ -408,10 +419,12 @@ function VisEditor(
     $scope.$listenAndDigestAsync(timefilter, 'refreshIntervalUpdate', updateRefreshInterval);
 
     // update the searchSource when filters update
-    $scope.$listen(queryFilter, 'update', function () {
-      $scope.filters = queryFilter.getFilters();
-      $scope.fetch();
-    });
+    const filterUpdateSubscription = queryFilter.getUpdates$().subscribe(
+      () => {
+        $scope.filters = queryFilter.getFilters();
+        $scope.fetch();
+      },
+    );
 
     // update the searchSource when query updates
     $scope.fetch = function () {
@@ -428,6 +441,7 @@ function VisEditor(
       }
       savedVis.destroy();
       stateMonitor.destroy();
+      filterUpdateSubscription.unsubscribe();
     });
 
     if (!$scope.chrome.getVisible()) {
@@ -472,7 +486,7 @@ function VisEditor(
 
           if (id) {
             toastNotifications.addSuccess({
-              title: i18n('kbn.visualize.topNavMenu.saveVisualization.successNotificationText', {
+              title: i18n.translate('kbn.visualize.topNavMenu.saveVisualization.successNotificationText', {
                 defaultMessage: `Saved '{visTitle}'`,
                 values: {
                   visTitle: savedVis.title,
@@ -494,7 +508,7 @@ function VisEditor(
               // url, not the unsaved one.
               chrome.trackSubUrlForApp('kibana:visualize', savedVisualizationParsedUrl);
 
-              const lastDashboardAbsoluteUrl = chrome.getNavLinkById('kibana:dashboard').lastSubUrl;
+              const lastDashboardAbsoluteUrl = getNewPlatform().start.core.chrome.navLinks.get('kibana:dashboard').url;
               const dashboardParsedUrl = absoluteToParsedUrl(lastDashboardAbsoluteUrl, chrome.getBasePath());
               dashboardParsedUrl.addQueryParameter(DashboardConstants.NEW_VISUALIZATION_ID_PARAM, savedVis.id);
               kbnUrl.change(dashboardParsedUrl.appPath);
@@ -511,7 +525,7 @@ function VisEditor(
         // eslint-disable-next-line
         console.error(error);
         toastNotifications.addDanger({
-          title: i18n('kbn.visualize.topNavMenu.saveVisualization.failureNotificationText', {
+          title: i18n.translate('kbn.visualize.topNavMenu.saveVisualization.failureNotificationText', {
             defaultMessage: `Error on saving '{visTitle}'`,
             values: {
               visTitle: savedVis.title,
@@ -541,7 +555,7 @@ function VisEditor(
     searchSource.setParent(searchSourceGrandparent);
 
     toastNotifications.addSuccess(
-      i18n('kbn.visualize.linkedToSearch.unlinkSuccessNotificationText', {
+      i18n.translate('kbn.visualize.linkedToSearch.unlinkSuccessNotificationText', {
         defaultMessage: `Unlinked from saved search '{searchTitle}'`,
         values: {
           searchTitle: savedVis.savedSearch.title
@@ -554,12 +568,10 @@ function VisEditor(
 
 
   $scope.getAdditionalMessage = () => {
-    return (
-      '<i class="kuiIcon fa-flask"></i>' +
-      i18n('kbn.visualize.experimentalVisInfoText', { defaultMessage: 'This visualization is marked as experimental.' }) +
-      ' ' +
-      vis.type.feedbackMessage
-    );
+    return '<i class="kuiIcon fa-flask"></i>' +
+    i18n.translate('kbn.visualize.experimentalVisInfoText', { defaultMessage: 'This visualization is marked as experimental.' }) +
+    ' ' +
+    vis.type.feedbackMessage;
   };
 
   init();
