@@ -18,6 +18,7 @@
  */
 
 import { MarkdownVisWrapper } from './markdown_vis_controller';
+import { i18n } from '@kbn/i18n';
 import { VisFactoryProvider } from 'ui/vis/vis_factory';
 import markdownVisParamsTemplate from './markdown_vis_params.html';
 import { VisTypesRegistryProvider } from 'ui/registry/vis_types';
@@ -29,7 +30,7 @@ import { DefaultEditorSize } from 'ui/vis/editor_size';
 // register the provider with the visTypes registry so that other know it exists
 VisTypesRegistryProvider.register(MarkdownVisProvider);
 
-function MarkdownVisProvider(Private, i18n) {
+function MarkdownVisProvider(Private) {
   const VisFactory = Private(VisFactoryProvider);
 
   // return the visType object, which kibana will use to display and configure new
@@ -39,7 +40,7 @@ function MarkdownVisProvider(Private, i18n) {
     title: 'Markdown',
     isAccessible: true,
     icon: 'visText',
-    description: i18n('markdownVis.markdownDescription', { defaultMessage: 'Create a document using markdown syntax' }),
+    description: i18n.translate('markdownVis.markdownDescription', { defaultMessage: 'Create a document using markdown syntax' }),
     visConfig: {
       component: MarkdownVisWrapper,
       defaults: {
