@@ -21,12 +21,16 @@ import PropTypes from 'prop-types';
 import React, { Component } from 'react';
 import * as Rx from 'rxjs';
 import { share } from 'rxjs/operators';
+import { isEqual, isEmpty, debounce } from 'lodash';
 import VisEditorVisualization from './vis_editor_visualization';
 import Visualization from './visualization';
 import VisPicker from './vis_picker';
 import PanelConfig from './panel_config';
 import brushHandler from '../lib/create_brush_handler';
-import { fetchIndexPatternFields } from '../lib/fetch_fields';
+import { fetchFields } from '../lib/fetch_fields';
+import { extractIndexPatterns } from '../../common/extract_index_patterns';
+
+const VIS_STATE_DEBOUNCE_DELAY = 200;
 
 class VisEditor extends Component {
   constructor(props) {
@@ -37,10 +41,11 @@ class VisEditor extends Component {
       model: props.visParams,
       dirty: false,
       autoApply: true,
-      visFields: props.visFields
+      visFields: props.visFields,
+      extractedIndexPatterns: [''],
     };
     this.onBrush = brushHandler(props.vis.API.timeFilter);
-    this.visDataSubject = new Rx.Subject();
+    this.visDataSubject = new Rx.BehaviorSubject(this.props.visData);
     this.visData$ = this.visDataSubject.asObservable().pipe(share());
   }
 
@@ -52,28 +57,52 @@ class VisEditor extends Component {
     return this.props.config.get(...args);
   };
 
-  handleUiState = (field, value) =>  {
+  handleUiState = (field, value) => {
     this.props.vis.uiStateVal(field, value);
   };
 
+  updateVisState = debounce(() => {
+    this.props.vis.params = this.state.model;
+    this.props.vis.updateState();
+  }, VIS_STATE_DEBOUNCE_DELAY);
+
   handleChange = async (partialModel) => {
-    const nextModel = { ...this.state.model, ...partialModel };
-    this.props.vis.params = nextModel;
-    if (this.state.autoApply) {
-      this.props.vis.updateState();
+    if (isEmpty(partialModel)) {
+      return;
     }
+    const hasTypeChanged = partialModel.type && this.state.model.type !== partialModel.type;
+    const nextModel = {
+      ...this.state.model,
+      ...partialModel,
+    };
+    let dirty = true;
+
+    if (this.state.autoApply || hasTypeChanged) {
+      this.updateVisState();
+
+      dirty = false;
+    }
+
+    if (this.props.isEditorMode) {
+      const extractedIndexPatterns = extractIndexPatterns(nextModel);
+
+      if (!isEqual(this.state.extractedIndexPatterns, extractedIndexPatterns)) {
+        fetchFields(extractedIndexPatterns)
+          .then(visFields => this.setState({
+            visFields,
+            extractedIndexPatterns,
+          }));
+      }
+    }
+
     this.setState({
+      dirty,
       model: nextModel,
-      dirty: !this.state.autoApply
-    });
-    const { params, fields } = this.props.vis;
-    fetchIndexPatternFields(params, fields).then(visFields => {
-      this.setState({ visFields });
     });
   };
 
   handleCommit = () => {
-    this.props.vis.updateState();
+    this.updateVisState();
     this.setState({ dirty: false });
   };
 
@@ -107,9 +136,9 @@ class VisEditor extends Component {
 
     if (model) {
       return (
-        <div className="tvbEditor">
+        <div className="tvbEditor" data-test-subj="tvbVisEditor">
           <div className="tvbEditor--hideForReporting">
-            <VisPicker model={model} onChange={this.handleChange} />
+            <VisPicker model={model} onChange={this.handleChange}/>
           </div>
           <VisEditorVisualization
             dirty={this.state.dirty}
@@ -118,15 +147,11 @@ class VisEditor extends Component {
             appState={this.appState}
             savedObj={this.props.savedObj}
             timeRange={this.props.timeRange}
-            onUiState={this.handleUiState}
             uiState={this.uiState}
-            onBrush={this.onBrush}
             onCommit={this.handleCommit}
             onToggleAutoApply={this.handleAutoApplyToggle}
-            onChange={this.handleChange}
             title={this.props.vis.title}
             description={this.props.vis.description}
-            dateFormat={this.props.config.get('dateFormat')}
             onDataChange={this.onDataChange}
           />
           <div className="tvbEditor--hideForReporting">
@@ -153,10 +178,14 @@ class VisEditor extends Component {
   componentDidUpdate() {
     this.props.renderComplete();
   }
+
+  componentWillUnmount() {
+    this.updateVisState.cancel();
+  }
 }
 
 VisEditor.defaultProps = {
-  visData: {}
+  visData: {},
 };
 
 VisEditor.propTypes = {
