@@ -27,31 +27,51 @@ function ReactEditorControllerProvider(Private, config) {
   class ReactEditorController {
     constructor(el, savedObj) {
       this.el = el;
-      this.savedObj = savedObj;
-      this.vis = savedObj.vis;
-      this.vis.fields = {};
+
+      this.state = {
+        savedObj: savedObj,
+        vis: savedObj.vis,
+        isLoaded: false,
+      };
     }
 
-    setDefaultIndexPattern = async () => {
+    fetchDefaultIndexPattern = async () => {
       const savedObjectsClient = chrome.getSavedObjectsClient();
       const indexPattern = await savedObjectsClient.get('index-pattern', config.get('defaultIndex'));
-      this.vis.params.default_index_pattern = indexPattern.attributes.title;
+
+      return indexPattern.attributes;
+    };
+
+    fetchDefaultParams = async () => {
+      const {
+        title,
+        timeFieldName,
+      } = await this.fetchDefaultIndexPattern();
+
+      this.state.vis.params.default_index_pattern = title;
+      this.state.vis.params.default_timefield = timeFieldName;
+      this.state.vis.fields = await fetchIndexPatternFields(this.state.vis);
+
+      this.state.isLoaded = true;
+    };
+
+    getComponent = () => {
+      return this.state.vis.type.editorConfig.component;
     };
 
     async render(params) {
-      const Component = this.vis.type.editorConfig.component;
+      const Component = this.getComponent();
 
-      await this.setDefaultIndexPattern();
-      const visFields = await fetchIndexPatternFields(this.vis.params, this.vis.fields);
+      !this.state.isLoaded && await this.fetchDefaultParams();
 
       render(
         <I18nContext>
           <Component
             config={config}
-            vis={this.vis}
-            visFields={visFields}
-            visParams={this.vis.params}
-            savedObj={this.savedObj}
+            vis={this.state.vis}
+            visFields={this.state.vis.fields}
+            visParams={this.state.vis.params}
+            savedObj={this.state.savedObj}
             timeRange={params.timeRange}
             renderComplete={() => {}}
             isEditorMode={true}
@@ -61,8 +81,6 @@ function ReactEditorControllerProvider(Private, config) {
         this.el);
     }
 
-    resize() {}
-
     destroy() {
       unmountComponentAtNode(this.el);
     }
@@ -70,7 +88,7 @@ function ReactEditorControllerProvider(Private, config) {
 
   return {
     name: 'react_editor',
-    handler: ReactEditorController
+    handler: ReactEditorController,
   };
 }
 
