@@ -1,3 +1,7 @@
+"use strict";
+
+var _new_platform = require("ui/new_platform");
+
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
  * license agreements. See the NOTICE file distributed with
@@ -16,10 +20,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+(0, _new_platform.onStart)(function (_ref) {
+  var core = _ref.core;
+  var timelionUiEnabled = core.injectedMetadata.getInjectedVar('timelionUiEnabled');
 
-import chrome from 'ui/chrome';
-
-const timelionUiEnabled = chrome.getInjected('timelionUiEnabled');
-if (timelionUiEnabled === false && chrome.navLinkExists('timelion')) {
-  chrome.getNavLinkById('timelion').hidden = true;
-}
+  if (timelionUiEnabled === false) {
+    core.chrome.navLinks.update('timelion', {
+      hidden: true
+    });
+  }
+});
\ No newline at end of file
