@@ -76,13 +76,11 @@ import { buildEsQuery, getEsQueryConfig, filterMatchesIndex } from '@kbn/es-quer
 import '../../promises';
 import { NormalizeSortRequestProvider } from './_normalize_sort_request';
 import { SearchRequestProvider } from '../fetch/request';
-import { SegmentedSearchRequestProvider } from '../fetch/request/segmented_search_request';
 
 import { searchRequestQueue } from '../search_request_queue';
 import { FetchSoonProvider } from '../fetch';
 import { FieldWildcardProvider } from '../../field_wildcard';
 import { getHighlightRequest } from '../../../../core_plugins/kibana/common/highlight';
-import { KbnError, OutdatedKuerySyntaxError } from '../../errors';
 
 const FIELDS = [
   'type',
@@ -112,12 +110,11 @@ function parseInitialFields(initialFields) {
 }
 
 function isIndexPattern(val) {
-  return Boolean(val && typeof val.toIndexList === 'function');
+  return Boolean(val && typeof val.getIndex === 'function');
 }
 
 export function SearchSourceProvider(Promise, Private, config) {
   const SearchRequest = Private(SearchRequestProvider);
-  const SegmentedSearchRequest = Private(SegmentedSearchRequestProvider);
   const normalizeSortRequest = Private(NormalizeSortRequestProvider);
   const fetchSoon = Private(FetchSoonProvider);
   const { fieldWildcardFilter } = Private(FieldWildcardProvider);
@@ -390,26 +387,6 @@ export function SearchSourceProvider(Promise, Private, config) {
       });
     }
 
-    onBeginSegmentedFetch(initFunction) {
-      const self = this;
-      return new Promise((resolve, reject) => {
-        function addRequest() {
-          const defer = Promise.defer();
-          const errorHandler = (request, error) => {
-            reject(error);
-            request.abort();
-          };
-          const req = new SegmentedSearchRequest({ source: self, defer, errorHandler, initFn: initFunction });
-
-          // Return promises created by the completion handler so that
-          // errors will bubble properly
-          return req.getCompletePromise().then(addRequest);
-        }
-
-        addRequest();
-      });
-    }
-
     async getSearchRequestBody() {
       const searchRequest = await this._flatten();
       return searchRequest.body;
@@ -602,15 +579,8 @@ export function SearchSourceProvider(Promise, Private, config) {
             _.set(flatData.body, '_source.includes', remainingFields);
           }
 
-          try {
-            const esQueryConfigs = getEsQueryConfig(config);
-            flatData.body.query = buildEsQuery(flatData.index, flatData.query, flatData.filters, esQueryConfigs);
-          } catch (e) {
-            if (e.message === 'OutdatedKuerySyntaxError') {
-              throw new OutdatedKuerySyntaxError();
-            }
-            throw new KbnError(e.message, KbnError);
-          }
+          const esQueryConfigs = getEsQueryConfig(config);
+          flatData.body.query = buildEsQuery(flatData.index, flatData.query, flatData.filters, esQueryConfigs);
 
           if (flatData.highlightAll != null) {
             if (flatData.highlightAll && flatData.body.query) {
