@@ -23,18 +23,19 @@ import angular from 'angular';
 import { fieldFormats } from '../registry/field_formats';
 import UtilsMappingSetupProvider from '../utils/mapping_setup';
 import { Notifier, toastNotifications } from '../notify';
+import { EuiButton, EuiFlexGroup, EuiFlexItem } from '@elastic/eui';
+import React from 'react';
 
 import { getComputedFields } from './_get_computed_fields';
 import { formatHit } from './_format_hit';
 import { IndexPatternsGetProvider } from './_get';
-import { IndexPatternsIntervalsProvider } from './_intervals';
 import { FieldList } from './_field_list';
 import { IndexPatternsFlattenHitProvider } from './_flatten_hit';
 import { IndexPatternsPatternCacheProvider } from './_pattern_cache';
 import { FieldsFetcherProvider } from './fields_fetcher_provider';
-import { IsUserAwareOfUnsupportedTimePatternProvider } from './unsupported_time_patterns';
 import { SavedObjectsClientProvider, findObjectByTitle } from '../saved_objects';
 import { i18n } from '@kbn/i18n';
+import { FormattedMessage } from '@kbn/i18n/react';
 
 export function getRoutes() {
   return {
@@ -52,11 +53,9 @@ export function IndexPatternProvider(Private, config, Promise, confirmModalPromi
   const getConfig = (...args) => config.get(...args);
   const getIds = Private(IndexPatternsGetProvider)('id');
   const fieldsFetcher = Private(FieldsFetcherProvider);
-  const intervals = Private(IndexPatternsIntervalsProvider);
   const mappingSetup = Private(UtilsMappingSetupProvider);
   const flattenHit = Private(IndexPatternsFlattenHitProvider);
   const patternCache = Private(IndexPatternsPatternCacheProvider);
-  const isUserAwareOfUnsupportedTimePattern = Private(IsUserAwareOfUnsupportedTimePatternProvider);
   const savedObjectsClient = Private(SavedObjectsClientProvider);
   const fieldformats = fieldFormats;
 
@@ -119,24 +118,33 @@ export function IndexPatternProvider(Private, config, Promise, confirmModalPromi
     }
 
     if (indexPattern.isUnsupportedTimePattern()) {
-      if (!isUserAwareOfUnsupportedTimePattern(indexPattern)) {
-        const warningTitle = i18n.translate('common.ui.indexPattern.warningTitle', {
-          defaultMessage: 'Support for time intervals was removed',
-        });
+      const warningTitle = i18n.translate('common.ui.indexPattern.warningTitle', {
+        defaultMessage: 'Support for time interval index patterns removed',
+      });
 
-        const warningText = i18n.translate('common.ui.indexPattern.warningText', {
-          defaultMessage: 'For more information, view the ["{title}" index pattern in management]({link})',
-          values: {
-            title: indexPattern.title,
-            link: kbnUrl.getRouteHref(indexPattern, 'edit'),
-          },
-        });
+      const warningText = i18n.translate('common.ui.indexPattern.warningText', {
+        defaultMessage: 'Currently querying all indices matching {index}. {title} should be migrated to a wildcard-based index pattern.',
+        values: {
+          title: indexPattern.title,
+          index: indexPattern.getIndex()
+        }
+      });
 
-        toastNotifications.addWarning({
-          title: warningTitle,
-          text: warningText,
-        });
-      }
+      toastNotifications.addWarning({
+        title: warningTitle,
+        text: (
+          <div>
+            <p>{warningText}</p>
+            <EuiFlexGroup justifyContent="flexEnd" gutterSize="s">
+              <EuiFlexItem grow={false}>
+                <EuiButton size="s" href={kbnUrl.getRouteHref(indexPattern, 'edit')}>
+                  <FormattedMessage id="common.ui.indexPattern.editIndexPattern" defaultMessage="Edit index pattern" />
+                </EuiButton>
+              </EuiFlexItem>
+            </EuiFlexGroup>
+          </div>
+        ),
+      });
     }
 
     return indexFields(indexPattern, forceFieldRefresh);
@@ -269,6 +277,16 @@ export function IndexPatternProvider(Private, config, Promise, confirmModalPromi
         .then(() => this);
     }
 
+    migrate(newTitle) {
+      return savedObjectsClient.update(type, this.id, {
+        title: newTitle,
+        intervalName: null
+      }).then(({ attributes: { title, intervalName } }) => {
+        this.title = title;
+        this.intervalName = intervalName;
+      }).then(() => this);
+    }
+
     // Get the source filtering configuration for that index.
     getSourceFiltering() {
       return {
@@ -329,47 +347,27 @@ export function IndexPatternProvider(Private, config, Promise, confirmModalPromi
       return _.where(this.fields, { scripted: true });
     }
 
-    getInterval() {
-      return this.intervalName && _.find(intervals, { name: this.intervalName });
-    }
+    getIndex() {
+      if (!this.isUnsupportedTimePattern()) {
+        return this.title;
+      }
 
-    toIndexList(start, stop, sortDirection) {
-      return this
-        .toDetailedIndexList(start, stop, sortDirection)
-        .then(detailedIndices => {
-          if (!Array.isArray(detailedIndices)) {
-            return detailedIndices.index;
-          }
-          return detailedIndices.map(({ index }) => index).join(',');
-        });
-    }
-
-    toDetailedIndexList(start, stop, sortDirection) {
-      return Promise.resolve().then(() => {
-        if (this.isTimeBasedInterval()) {
-          return intervals.toIndexList(
-            this.title, this.getInterval(), start, stop, sortDirection
-          );
-        }
-
-        return [
-          {
-            index: this.title,
-            min: -Infinity,
-            max: Infinity
-          }
-        ];
-      });
+      // Take a time-based interval index pattern title (like [foo-]YYYY.MM.DD[-bar]) and turn it
+      // into the actual index (like foo-*-bar) by replacing anything not inside square brackets
+      // with a *.
+      const regex = /\[[^\]]*]/g; // Matches text inside brackets
+      const splits = this.title.split(regex); // e.g. ['', 'YYYY.MM.DD', ''] from the above example
+      const matches = this.title.match(regex); // e.g. ['[foo-]', '[-bar]'] from the above example
+      return splits.map((split, i) => {
+        const match = i >= matches.length ? '' : matches[i].replace(/[\[\]]/g, '');
+        return `${split.length ? '*' : ''}${match}`;
+      }).join('');
     }
 
     isTimeBased() {
       return !!this.timeFieldName && (!this.fields || !!this.getTimeField());
     }
 
-    isTimeBasedInterval() {
-      return this.isTimeBased() && !!this.getInterval();
-    }
-
     isUnsupportedTimePattern() {
       return !!this.intervalName;
     }
