@@ -1,4 +1,4 @@
-'use strict';
+"use strict";
 
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
@@ -18,7 +18,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 module.exports = {
   plugins: [require('autoprefixer')({
     browsers: ['last 2 versions', '> 5%', 'Safari 7' // for PhantomJS support: https://github.com/elastic/kibana/issues/27136
